==> gnome-builder-44.2.tar.xz: gnome-builder-44.2/src/plugins/sessionui/sessionui-plugin.c <==
/* sessionui-plugin.c
 *
 * Copyright 2022 Christian Hergert <chergert@redhat.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#define G_LOG_DOMAIN "sessionui-plugin"

#include "config.h"

#include <libpeas/peas.h>

#include <libide-editor.h>
#include <libide-gui.h>

#include "gbp-sessionui-editor-page-addin.h"
#include "gbp-sessionui-workbench-addin.h"

_IDE_EXTERN void
_gbp_sessionui_register_types (PeasObjectModule *module)
{
  peas_object_module_register_extension_type (module,
                                              IDE_TYPE_EDITOR_PAGE_ADDIN,
                                              GBP_TYPE_SESSIONUI_EDITOR_PAGE_ADDIN);
  peas_object_module_register_extension_type (module,
                                              IDE_TYPE_WORKBENCH_ADDIN,
                                              GBP_TYPE_SESSIONUI_WORKBENCH_ADDIN);
}

==> gnome-builder_48.2.orig.tar.xz: gnome-builder-48.2/src/plugins/sessionui/sessionui-plugin.c <==
/* sessionui-plugin.c
 *
 * Copyright 2022 Christian Hergert <chergert@redhat.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#define G_LOG_DOMAIN "sessionui-plugin"

#include "config.h"

#include <libpeas.h>

#include <libide-editor.h>
#include <libide-gui.h>

#include "gbp-sessionui-editor-page-addin.h"
#include "gbp-sessionui-workbench-addin.h"

_IDE_EXTERN void
_gbp_sessionui_register_types (PeasObjectModule *module)
{
  peas_object_module_register_extension_type (module,
                                              IDE_TYPE_EDITOR_PAGE_ADDIN,
                                              GBP_TYPE_SESSIONUI_EDITOR_PAGE_ADDIN);
  peas_object_module_register_extension_type (module,
                                              IDE_TYPE_WORKBENCH_ADDIN,
                                              GBP_TYPE_SESSIONUI_WORKBENCH_ADDIN);
}
